package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

public class X509Extensions extends ASN1Encodable {
   public static final DERObjectIdentifier SubjectDirectoryAttributes = new DERObjectIdentifier("2.5.29.9");
   public static final DERObjectIdentifier SubjectKeyIdentifier = new DERObjectIdentifier("2.5.29.14");
   public static final DERObjectIdentifier KeyUsage = new DERObjectIdentifier("2.5.29.15");
   public static final DERObjectIdentifier PrivateKeyUsagePeriod = new DERObjectIdentifier("2.5.29.16");
   public static final DERObjectIdentifier SubjectAlternativeName = new DERObjectIdentifier("2.5.29.17");
   public static final DERObjectIdentifier IssuerAlternativeName = new DERObjectIdentifier("2.5.29.18");
   public static final DERObjectIdentifier BasicConstraints = new DERObjectIdentifier("2.5.29.19");
   public static final DERObjectIdentifier CRLNumber = new DERObjectIdentifier("2.5.29.20");
   public static final DERObjectIdentifier ReasonCode = new DERObjectIdentifier("2.5.29.21");
   public static final DERObjectIdentifier InstructionCode = new DERObjectIdentifier("2.5.29.23");
   public static final DERObjectIdentifier InvalidityDate = new DERObjectIdentifier("2.5.29.24");
   public static final DERObjectIdentifier DeltaCRLIndicator = new DERObjectIdentifier("2.5.29.27");
   public static final DERObjectIdentifier IssuingDistributionPoint = new DERObjectIdentifier("2.5.29.28");
   public static final DERObjectIdentifier CertificateIssuer = new DERObjectIdentifier("2.5.29.29");
   public static final DERObjectIdentifier NameConstraints = new DERObjectIdentifier("2.5.29.30");
   public static final DERObjectIdentifier CRLDistributionPoints = new DERObjectIdentifier("2.5.29.31");
   public static final DERObjectIdentifier CertificatePolicies = new DERObjectIdentifier("2.5.29.32");
   public static final DERObjectIdentifier PolicyMappings = new DERObjectIdentifier("2.5.29.33");
   public static final DERObjectIdentifier AuthorityKeyIdentifier = new DERObjectIdentifier("2.5.29.35");
   public static final DERObjectIdentifier PolicyConstraints = new DERObjectIdentifier("2.5.29.36");
   public static final DERObjectIdentifier ExtendedKeyUsage = new DERObjectIdentifier("2.5.29.37");
   public static final DERObjectIdentifier FreshestCRL = new DERObjectIdentifier("2.5.29.46");
   public static final DERObjectIdentifier InhibitAnyPolicy = new DERObjectIdentifier("2.5.29.54");
   public static final DERObjectIdentifier AuthorityInfoAccess = new DERObjectIdentifier("1.3.6.1.5.5.7.1.1");
   public static final DERObjectIdentifier SubjectInfoAccess = new DERObjectIdentifier("1.3.6.1.5.5.7.1.11");
   public static final DERObjectIdentifier LogoType = new DERObjectIdentifier("1.3.6.1.5.5.7.1.12");
   public static final DERObjectIdentifier BiometricInfo = new DERObjectIdentifier("1.3.6.1.5.5.7.1.2");
   public static final DERObjectIdentifier QCStatements = new DERObjectIdentifier("1.3.6.1.5.5.7.1.3");
   public static final DERObjectIdentifier AuditIdentity = new DERObjectIdentifier("1.3.6.1.5.5.7.1.4");
   public static final DERObjectIdentifier NoRevAvail = new DERObjectIdentifier("2.5.29.56");
   public static final DERObjectIdentifier TargetInformation = new DERObjectIdentifier("2.5.29.55");
   private Hashtable extensions;
   private Vector ordering;

   public static X509Extensions getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static X509Extensions getInstance(Object obj) {
      if (obj != null && !(obj instanceof X509Extensions)) {
         if (obj instanceof ASN1Sequence) {
            return new X509Extensions((ASN1Sequence)obj);
         } else if (obj instanceof ASN1TaggedObject) {
            return getInstance(((ASN1TaggedObject)obj).getObject());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (X509Extensions)obj;
      }
   }

   public X509Extensions(ASN1Sequence seq) {
      ASN1Sequence var10000 = seq;
      super();
      Hashtable seq1;
      seq1 = new Hashtable.<init>();
      this.extensions = seq1;
      Vector seq2;
      seq2 = new Vector.<init>();
      this.ordering = seq2;

      ASN1Sequence var2;
      for(Enumeration seq3 = var10000.getObjects(); seq3.hasMoreElements(); this.ordering.addElement(var2.getObjectAt(0))) {
         if ((var2 = ASN1Sequence.getInstance(seq3.nextElement())).size() == 3) {
            Hashtable var7 = this.extensions;
            DEREncodable var10001 = var2.getObjectAt(0);
            DERBoolean var3 = DERBoolean.getInstance(var2.getObjectAt(1));
            var7.put(var10001, new X509Extension(var3, ASN1OctetString.getInstance(var2.getObjectAt(2))));
         } else {
            if (var2.size() != 2) {
               throw new IllegalArgumentException("Bad sequence size: " + var2.size());
            }

            this.extensions.put(var2.getObjectAt(0), new X509Extension(false, ASN1OctetString.getInstance(var2.getObjectAt(1))));
         }
      }

   }

   public X509Extensions(Hashtable extensions) {
      this((Vector)null, (Hashtable)extensions);
   }

   public X509Extensions(Vector ordering, Hashtable extensions) {
      Hashtable var3;
      var3 = new Hashtable.<init>();
      this.extensions = var3;
      Vector var7;
      var7 = new Vector.<init>();
      this.ordering = var7;
      Enumeration ordering1;
      if (ordering == null) {
         ordering1 = extensions.keys();
      } else {
         ordering1 = ordering.elements();
      }

      while(ordering1.hasMoreElements()) {
         this.ordering.addElement(ordering1.nextElement());
      }

      Enumeration var8 = this.ordering.elements();

      while(var8.hasMoreElements()) {
         DERObjectIdentifier ordering2;
         X509Extension var4 = (X509Extension)extensions.get(ordering2 = (DERObjectIdentifier)var8.nextElement());
         this.extensions.put(ordering2, var4);
      }

   }

   public X509Extensions(Vector objectIDs, Vector values) {
      Vector var10000 = objectIDs;
      super();
      Hashtable objectIDs1;
      objectIDs1 = new Hashtable.<init>();
      this.extensions = objectIDs1;
      objectIDs = new Vector.<init>();
      this.ordering = objectIDs;
      Enumeration objectIDs2 = var10000.elements();

      while(objectIDs2.hasMoreElements()) {
         this.ordering.addElement(objectIDs2.nextElement());
      }

      int objectIDs3 = 0;

      for(Enumeration var3 = this.ordering.elements(); var3.hasMoreElements(); ++objectIDs3) {
         DERObjectIdentifier var4 = (DERObjectIdentifier)var3.nextElement();
         X509Extension var5 = (X509Extension)values.elementAt(objectIDs3);
         this.extensions.put(var4, var5);
      }

   }

   public Enumeration oids() {
      return this.ordering.elements();
   }

   public X509Extension getExtension(DERObjectIdentifier oid) {
      return (X509Extension)this.extensions.get(oid);
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      Enumeration var2 = this.ordering.elements();

      while(var2.hasMoreElements()) {
         DERObjectIdentifier var3 = (DERObjectIdentifier)var2.nextElement();
         X509Extension var4;
         X509Extension var10000 = var4 = (X509Extension)this.extensions.get(var3);
         ASN1EncodableVector var5;
         ASN1EncodableVector var10001 = var5 = new ASN1EncodableVector;
         var5.<init>();
         var10001.add(var3);
         if (var10000.isCritical()) {
            DERBoolean var6;
            var6 = new DERBoolean.<init>(true);
            var5.add(var6);
         }

         var5.add(var4.getValue());
         var1.add(new DERSequence(var5));
      }

      return new DERSequence(var1);
   }

   public boolean equivalent(X509Extensions other) {
      if (this.extensions.size() != other.extensions.size()) {
         return false;
      } else {
         Enumeration var2 = this.extensions.keys();

         while(var2.hasMoreElements()) {
            Object var3 = var2.nextElement();
            if (!this.extensions.get(var3).equals(other.extensions.get(var3))) {
               return false;
            }
         }

         return true;
      }
   }
}
